about summary refs log tree commit diff
path: root/pkgs/development/compilers
diff options
context:
space:
mode:
authorJörg Thalheim <Mic92@users.noreply.github.com>2019-01-28 16:14:57 +0000
committerGitHub <noreply@github.com>2019-01-28 16:14:57 +0000
commit6f6900495d1a72f172115e761c4fde8be98ef619 (patch)
tree8b7cad9b9c2d737b9c4a7287609f3919122d9ed2 /pkgs/development/compilers
parentd54fbbebbb5195d6dea3b7cf6185c90554b4d6c2 (diff)
parentc340704bd3a7784e2d5dd806ee528a243dea9172 (diff)
downloadnixlib-6f6900495d1a72f172115e761c4fde8be98ef619.tar
nixlib-6f6900495d1a72f172115e761c4fde8be98ef619.tar.gz
nixlib-6f6900495d1a72f172115e761c4fde8be98ef619.tar.bz2
nixlib-6f6900495d1a72f172115e761c4fde8be98ef619.tar.lz
nixlib-6f6900495d1a72f172115e761c4fde8be98ef619.tar.xz
nixlib-6f6900495d1a72f172115e761c4fde8be98ef619.tar.zst
nixlib-6f6900495d1a72f172115e761c4fde8be98ef619.zip
Merge pull request #54323 from lblasc/rust132
rust: 1.31.0 -> 1.32.0
Diffstat (limited to 'pkgs/development/compilers')
-rw-r--r--pkgs/development/compilers/llvm/7/llvm.nix9
-rw-r--r--pkgs/development/compilers/rust/bootstrap.nix16
-rw-r--r--pkgs/development/compilers/rust/cargo.nix4
-rw-r--r--pkgs/development/compilers/rust/default.nix11
-rw-r--r--pkgs/development/compilers/rust/patches/disable-test-inherit-env.patch10
-rw-r--r--pkgs/development/compilers/rust/rustc.nix8
6 files changed, 24 insertions, 34 deletions
diff --git a/pkgs/development/compilers/llvm/7/llvm.nix b/pkgs/development/compilers/llvm/7/llvm.nix
index 0eb946a0a837..533333d49723 100644
--- a/pkgs/development/compilers/llvm/7/llvm.nix
+++ b/pkgs/development/compilers/llvm/7/llvm.nix
@@ -53,6 +53,15 @@ in stdenv.mkDerivation (rec {
       url = "https://salsa.debian.org/pkg-llvm-team/llvm-toolchain/raw/5a7d283d4e00bc4822c7b0226e593c344c8f6050/debian/patches/pr39427-misscompile.diff";
       sha256 = "03mpydsaw0xvcp7kb4sgjzcl5v22620r5z78kv3mz5wp7sn76fg5";
     })
+    # backport, fix building rust crates with lto
+    (fetchpatch {
+      url = "https://github.com/llvm-mirror/llvm/commit/da1fb72bb305d6bc1f3899d541414146934bf80f.patch";
+      sha256 = "0p81gkhc1xhcx0hmnkwyhrn8x8l8fd24xgaj1whni29yga466dwc";
+    })
+    (fetchpatch {
+      url = "https://github.com/llvm-mirror/llvm/commit/cc1f2a595ead516812a6c50398f0f3480ebe031f.patch";
+      sha256 = "0k6k1p5yisgwx417a67s7sr9930rqh1n0zv5jvply8vjjy4b3kf8";
+    })
   ];
 
   postPatch = optionalString stdenv.isDarwin ''
diff --git a/pkgs/development/compilers/rust/cargo.nix b/pkgs/development/compilers/rust/cargo.nix
index 02ea7ebbbfbf..a7e2a40597bc 100644
--- a/pkgs/development/compilers/rust/cargo.nix
+++ b/pkgs/development/compilers/rust/cargo.nix
@@ -10,8 +10,8 @@ rustPlatform.buildRustPackage rec {
   inherit version src patches;
 
   # the rust source tarball already has all the dependencies vendored, no need to fetch them again
-  cargoVendorDir = "src/vendor";
-  preBuild = "cd src; pushd tools/cargo";
+  cargoVendorDir = "vendor";
+  preBuild = "pushd src/tools/cargo";
   postBuild = "popd";
 
   passthru.rustc = rustc;
diff --git a/pkgs/development/compilers/rust/default.nix b/pkgs/development/compilers/rust/default.nix
index 1f24157eea42..9640cd9b577e 100644
--- a/pkgs/development/compilers/rust/default.nix
+++ b/pkgs/development/compilers/rust/default.nix
@@ -7,11 +7,11 @@
 
 let
   rustPlatform = recurseIntoAttrs (makeRustPlatform (callPackage ./bootstrap.nix {}));
-  version = "1.31.0";
-  cargoVersion = "1.31.0";
+  version = "1.32.0";
+  cargoVersion = "1.32.0";
   src = fetchurl {
     url = "https://static.rust-lang.org/dist/rustc-${version}-src.tar.gz";
-    sha256 = "01pg2619bwjnhjbphryrbkwaz0lw8cfffm4xlz35znzipb04vmcs";
+    sha256 = "0ji2l9xv53y27xy72qagggvq47gayr5lcv2jwvmfirx029vlqnac";
   };
 in rec {
   rustc = callPackage ./rustc.nix {
@@ -22,11 +22,6 @@ in rec {
 
       # Re-evaluate if this we need to disable this one
       #./patches/stdsimd-disable-doctest.patch
-
-      # Fails on hydra - not locally; the exact reason is unknown.
-      # Comments in the test suggest that some non-reproducible environment
-      # variables such $RANDOM can make it fail.
-      ./patches/disable-test-inherit-env.patch
     ];
 
     withBundledLLVM = false;
diff --git a/pkgs/development/compilers/rust/patches/disable-test-inherit-env.patch b/pkgs/development/compilers/rust/patches/disable-test-inherit-env.patch
deleted file mode 100644
index fcb75ed098ec..000000000000
--- a/pkgs/development/compilers/rust/patches/disable-test-inherit-env.patch
+++ /dev/null
@@ -1,10 +0,0 @@
---- rustc-1.26.2-src.org/src/libstd/process.rs	2018-06-01 21:40:11.000000000 +0100
-+++ rustc-1.26.2-src/src/libstd/process.rs	2018-06-08 07:50:23.023828658 +0100
-@@ -1745,6 +1745,7 @@
-     }
- 
-     #[test]
-+    #[ignore]
-     fn test_inherit_env() {
-         use env;
- 
diff --git a/pkgs/development/compilers/rust/rustc.nix b/pkgs/development/compilers/rust/rustc.nix
index c6350e42bc23..1f43832716bd 100644
--- a/pkgs/development/compilers/rust/rustc.nix
+++ b/pkgs/development/compilers/rust/rustc.nix
@@ -1,6 +1,6 @@
 { stdenv, targetPackages, removeReferencesTo
 , fetchurl, fetchgit, fetchzip, file, python2, tzdata, ps
-, llvm, jemalloc, ncurses, darwin, rustPlatform, git, cmake, curl
+, llvm, ncurses, darwin, rustPlatform, git, cmake, curl
 , which, libffi, gdb
 , version
 , withBundledLLVM ? false
@@ -20,8 +20,6 @@ let
 
   llvmShared = llvm.override { enableSharedLibraries = true; };
 
-  prefixedJemalloc = jemalloc.override { stripPrefix = false; };
-
   target = builtins.replaceStrings [" "] [","] (builtins.toString targets);
 in
 
@@ -62,7 +60,6 @@ stdenv.mkDerivation {
   configureFlags = configureFlags
                 ++ [ "--enable-local-rust" "--local-rust-root=${rustPlatform.rust.rustc}" "--enable-rpath"
                      "--enable-vendor"
-                     "--jemalloc-root=${prefixedJemalloc}/lib"
                      "--default-linker=${targetPackages.stdenv.cc}/bin/cc" ]
                 ++ optional (!withBundledLLVM) [ "--enable-llvm-link-shared" "--llvm-root=${llvmShared}" ]
                 ++ optional (targets != []) "--target=${target}";
@@ -85,7 +82,6 @@ stdenv.mkDerivation {
     patchShebangs src/etc
 
     ${optionalString (!withBundledLLVM) ''rm -rf src/llvm''}
-    rm -rf src/jemalloc
 
     # Fix the configure script to not require curl as we won't use it
     sed -i configure \
@@ -97,7 +93,7 @@ stdenv.mkDerivation {
     # https://github.com/rust-lang/rust/issues/39522
     echo removing gdb-version-sensitive tests...
     find src/test/debuginfo -type f -execdir grep -q ignore-gdb-version '{}' \; -print -delete
-    rm src/test/debuginfo/{borrowed-c-style-enum.rs,c-style-enum-in-composite.rs,gdb-pretty-struct-and-enums-pre-gdb-7-7.rs,generic-enum-with-different-disr-sizes.rs}
+    rm src/test/debuginfo/{borrowed-c-style-enum.rs,c-style-enum-in-composite.rs,gdb-pretty-struct-and-enums.rs,generic-enum-with-different-disr-sizes.rs}
 
     # Useful debugging parameter
     # export VERBOSE=1
diff --git a/pkgs/development/compilers/rust/bootstrap.nix b/pkgs/development/compilers/rust/bootstrap.nix
index 9528d798618f..ddef4adf0a0d 100644
--- a/pkgs/development/compilers/rust/bootstrap.nix
+++ b/pkgs/development/compilers/rust/bootstrap.nix
@@ -3,16 +3,16 @@
 let
   # Note: the version MUST be one version prior to the version we're
   # building
-  version = "1.30.1";
+  version = "1.31.1";
 
   # fetch hashes by running `print-hashes.sh 1.30.0`
   hashes = {
-    i686-unknown-linux-gnu = "c61655977fb16decf0ceb76043b9ae2190927aa9cc24f013d444384dcab99bbf";
-    x86_64-unknown-linux-gnu = "a01a493ed8946fc1c15f63e74fc53299b26ebf705938b4d04a388a746dfdbf9e";
-    armv7-unknown-linux-gnueabihf = "9b3b6df02a2a92757e4993a7357fdd02e07b60101a748b4618e6ae1b90bc1b6b";
-    aarch64-unknown-linux-gnu = "6d87d81561285abd6c1987e07b60b2d723936f037c4b46eedcc12e8566fd3874";
-    i686-apple-darwin = "a7c14b18e96406d9f43d69d0f984b2fa6f92cc7b7b37e2bb7b70b6f44b02b083";
-    x86_64-apple-darwin = "3ba1704a7defe3d9a6f0c1f68792c084da83bcba85e936d597bac0c019914b94";
+    i686-unknown-linux-gnu = "1e77e5e8c745320faad9ce6f319a77b4a2e75d972eb68a195acd081ad910ab6d";
+    x86_64-unknown-linux-gnu = "a64685535d0c457f49a8712a096a5c21564cd66fd2f7da739487f028192ebe3c";
+    armv7-unknown-linux-gnueabihf = "11c717b781a7af5bdc829894139f8f45d4c12a061f7f9e39481f21426a04eb21";
+    aarch64-unknown-linux-gnu = "29a7c6eb536fefd0ca459e48dfaea006aa8bff8a87aa82a9b7d483487033632a";
+    i686-apple-darwin = "46566dc25fcbd8badc9950b8c9f9b0faeca065b5a09cd96258e4f4b10d686aed";
+    x86_64-apple-darwin = "8398b1b303bdf0e7605d08b87070a514a4f588797c6fb3593718cb9cec233ad6";
   };
 
   platform =
@@ -3,16 +3,16 @@
 
-  # fetch hashes by running `print-hashes.sh 1.30.0`
+  # fetch hashes by running `print-hashes.sh 1.31.1`
   hashes = {